library(tidyverse)
library(shiny)
library(shinydashboard)
library(DT)

load("olympics.RData")

ui <- dashboardPage(
    dashboardHeader(title = "Olympic Medals"),                   # Title of the dashboard
    dashboardSidebar( 
        sliderInput("years", h4("Years"),                        # Element 1: year selection
                    min = 1895, max = 2015, 
                    value = c(1895, 2015), step = 5, sep = ""),
        checkboxGroupInput("season", h4("Season"),               # Element 2: season selection
                           choices = unique(olympics$Season),
                           selected = c("Summer", "Winter"))
        ),
    
    ####### NEW ELEMENTS BELOW !!!!!
    dashboardBody(
        DT::dataTableOutput("table_1")
    )
)

server <- function(input, output){
    ####### NEW ELEMENTS BELOW !!!!!
    data <- reactive({                # Creates the dynamic data
        olympics %>%                  # Filter years, seasons & gender
            filter(Year >= input$years[1], 
                   Year <= input$years[2],
                   Season %in% input$season) 
    })
    
    output$table_1 <- DT::renderDataTable(data()) # Create the output object!
    
}

# Run the app ----
shinyApp(ui = ui, server = server)