library(tidyverse)
library(shiny)
library(shinydashboard)
library(DT)

load("olympics.RData")

ui <- fluidPage( 
        sliderInput("years", h4("Years"),                        # Element 1: year selection
                    min = 1895, max = 2015, 
                    value = c(1895, 2015), step = 5, sep = ""),
        checkboxGroupInput("season", h4("Season"),               # Element 2: season selection
                           choices = unique(olympics$Season),
                           selected = c("Summer", "Winter")),
        checkboxGroupInput("gender", h4("Gender"),               # Element 3: gender selection
                           choices = list("Women" = "Women", 
                                          "Men" = "Men"),
                           selected = c("Women", "Men")),
        numericInput("max_country", h4("Max number countries"),  # Element 4: nb of countries displayed
                     min = 2, max = 12, step = 1, value = 6),
  
        plotOutput("plot", height = 300),        # To the outputs, directly
        DT::dataTableOutput("table_1")
)

server <- function(input, output){
    data <- reactive({                # Creates the dynamic data
        olympics %>%                  # Filter years, seasons & gender
            filter(Year >= input$years[1], 
                   Year <= input$years[2],
                   Season %in% input$season,
                   Gender %in% input$gender) 
    })
    
    output$table_1 <- DT::renderDataTable({data()})
    
    ####### NEW ELEMENTS BELOW !!!!!
    filter_country <- reactive({            # Performs a filter to limit countries
        data() %>% 
            group_by(Country) %>%           # Analysis by country
            summarise(nb_medals = n()) %>%  # Sum number of medals
            arrange(desc(nb_medals)) %>%    # Order
            head(input$max_country) %>%     # Keep only max_country
            pull(Country)                   # Keep only the Country column/variable
    }) 
    
    
    output$plot <- renderPlot({
        data() %>% 
            filter(Country %in% filter_country()) %>%
            ggplot(aes(x = Year, fill = Country)) + geom_bar()
    }, height = 300)
    
    
}

# Run the app ----
shinyApp(ui = ui, server = server)